@@ -25,25 +25,7 @@ if test x"$NO_MAKE" != x"yes"; then
     make $MAKE_ARGS -C $top_dir > /dev/null || exit 1
 fi
 
-if test -z "$CUTTER"; then
-    CUTTER="`make -s -C $top_dir echo-cutter`"
-fi
-export CUTTER
-
-if test -z "$RUBY"; then
-    RUBY="`make -s -C $top_dir echo-ruby`"
-fi
-export RUBY
-
-if test -z "$GROONGA"; then
-    GROONGA="`make -s -C $top_dir echo-groonga`"
-fi
-export GROONGA
-
-if test -z "$GROONGA_BENCHMARK"; then
-    GROONGA_BENCHMARK="`make -s -C $top_dir echo-groonga-benchmark`"
-fi
-export GROONGA_BENCHMARK
+. "${top_dir}/config.sh"
 
 TZ=Asia/Tokyo
 export TZ
@@ -76,6 +58,9 @@ CUTTER_ARGS="$CUTTER_ARGS --exclude-file test-performance.so"
 GRN_PLUGINS_DIR="$top_dir/plugins"
 export GRN_PLUGINS_DIR
 
+GRN_RUBY_SCRIPTS_DIR="$top_dir/lib/mrb/scripts"
+export GRN_RUBY_SCRIPTS_DIR
+
 case `uname` in
     Darwin)
 	DYLD_LIBRARY_PATH="$top_dir/lib/.libs:$DYLD_LIBRARY_PATH"
@@ -87,8 +72,8 @@ case `uname` in
 	;;
 esac
 
-tmpfs=/dev/shm
-if test -e $tmpfs; then
+tmpfs=/run/shm
+if test -d $tmpfs -a -w $tmpfs; then
     rm -rf "$BASE_DIR/tmp"
     ln -s $tmpfs "$BASE_DIR/tmp"
 fi
